OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Merki",
    "Tagged files" : "Merktar skrár",
    "Select tags to filter by" : "Veldu merki til að sía eftir",
    "Please select tags to filter by" : "Veldu merki til að sía eftir",
    "No files found for the selected tags" : "Engar skrár fundust með völdum merkjum",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Kerfismerkjum</strong> á skrá hefur verið breytt",
    "You assigned system tag %3$s" : "Þú úthlutaðir kerfismerkinu %3$s",
    "%1$s assigned system tag %3$s" : "%1$s úthlutaði kerfismerki %3$s",
    "You unassigned system tag %3$s" : "Þú tókst af úthlutun kerfismerkisins %3$s",
    "%1$s unassigned system tag %3$s" : "%1$s tók af úthlutun kerfismerkis %3$s",
    "You created system tag %2$s" : "Þú bjóst til kerfismerkið %2$s",
    "%1$s created system tag %2$s" : "%1$s bjó til kerfismerki %2$s",
    "You deleted system tag %2$s" : "Þú eyddir kerfismerkinu %2$s",
    "%1$s deleted system tag %2$s" : "%1$s eyddi kerfismerki %2$s",
    "You updated system tag %3$s to %2$s" : "Þú uppfærðir kerfismerki %3$s í %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppfærði kerfismerki %3$s í %2$s",
    "You assigned system tag %3$s to %2$s" : "Þú úthlutaðir kerfismerki %3$s á %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s úthlutaði kerfismerki %3$s á %2$s",
    "You unassigned system tag %3$s from %2$s" : "Þú tókst kerfismerkið %3$s af %2$s",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s tók kerfismerki %3$s af %2$s",
    "%s (restricted)" : "%s (takmarkaður aðgangur)",
    "%s (invisible)" : "%s (ósýnilegt)",
    "No files in here" : "Engar skrár hér",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Name" : "Heiti",
    "Size" : "Stærð",
    "Modified" : "Breytt"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
